@@ -673,8 +673,14 @@ class Enforcer(object):
             # the default deprecated policy, override the new policy's default
             # with the old check string. This should prevents unwanted exposure
             # to APIs on upgrade.
+            # There's one exception to this: When we generate a sample policy,
+            # we set the deprecated rule name to reference the new rule. If we
+            # see that the deprecated override rule is just the new rule, then
+            # we shouldn't mess with it.
             if (self.file_rules[deprecated_rule.name].check
-                    != _parser.parse_rule(deprecated_rule.check_str)):
+                    != _parser.parse_rule(deprecated_rule.check_str) and
+                    str(self.file_rules[deprecated_rule.name].check)
+                    != 'rule:%s' % default.name):
                 if default.name not in self.file_rules.keys():
                     self.rules[default.name] = self.file_rules[
                         deprecated_rule.name
@@ -693,10 +699,9 @@ class Enforcer(object):
         if (deprecated_rule.check_str != default.check_str
                 and default.name not in self.file_rules):
 
-            default.check = _parser.parse_rule(
-                default.check_str + ' or ' +
-                deprecated_rule.check_str
-            )
+            default.check = OrCheck([_parser.parse_rule(cs) for cs in
+                                     [default.check_str,
+                                      deprecated_rule.check_str]])
             if not self.suppress_deprecation_warnings:
                 warnings.warn(deprecated_msg)
 
